{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#clean_vcf.cwl",
            "label": "clean-vcf",
            "doc": "This tool will clean a VCF for use in the OxoG workflow.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                }
            ],
            "inputs": [
                {
                    "id": "#clean_vcf.cwl/vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                }
            ],
            "baseCommand": "/opt/oxog_scripts/clean_vcf.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            },
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.cleaned.vcf"
                    },
                    "id": "#clean_vcf.cwl/clean-vcf/clean_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#extract_snv.cwl",
            "label": "extract_snvs",
            "doc": "This tool will extract SNVs from INDEL VCFs\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                }
            ],
            "inputs": [
                {
                    "id": "#extract_snv.cwl/vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.extracted-SNVs.vcf.gz"
                    },
                    "id": "#extract_snv.cwl/extract_snvs/extracted_snvs"
                }
            ],
            "baseCommand": "/opt/oxog_scripts/extract_snvs_from_indels.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "CommandLineTool",
            "id": "#normalize.cwl",
            "label": "normalize",
            "doc": "This tool will normalize an INDEL VCF using bcf-tools norm.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                }
            ],
            "inputs": [
                {
                    "id": "#normalize.cwl/vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#normalize.cwl/ref",
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".fai"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#normalize.cwl/normalized-vcf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.normalized.vcf.gz"
                    }
                }
            ],
            "baseCommand": "/opt/oxog_scripts/normalize.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "CommandLineTool",
            "id": "#pass-filter.cwl",
            "label": "pass-filter",
            "doc": "This tool will pass-filter a VCF.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#pass-filter.cwl/vcfdir",
                    "type": "Directory",
                    "doc": "The directory containing the files"
                },
                {
                    "id": "#pass-filter.cwl/filesToFilter",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "doc": "The names of the files that will actually be filtered"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.pass-filtered.vcf.gz"
                    },
                    "id": "#pass-filter.cwl/pass-filter/output"
                }
            ],
            "arguments": [
                "$(inputs.vcfdir.path)",
                "$(inputs.filesToFilter)"
            ],
            "baseCommand": "/opt/oxog_scripts/pass_filter.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "Workflow",
            "doc": "This workflow will perform preprocessing steps on VCFs for the OxoG/Variantbam/Annotation workflow.\n",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "name": "#PreprocessedFilesType.yaml/PreprocessedFileset",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/mergedVcfs",
                                    "type": [
                                        "null",
                                        {
                                            "type": "array",
                                            "items": "File"
                                        }
                                    ]
                                },
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/normalizedVcfs",
                                    "type": [
                                        "null",
                                        {
                                            "type": "array",
                                            "items": "File"
                                        }
                                    ]
                                },
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/extractedSnvs",
                                    "type": [
                                        "null",
                                        {
                                            "type": "array",
                                            "items": "File"
                                        }
                                    ]
                                },
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/cleanedVcfs",
                                    "type": [
                                        "null",
                                        {
                                            "type": "array",
                                            "items": "File"
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "\nfunction filterForIndels(inArr)\n{\n\tvar arr = [];\n\tfor (var i = 0; i < inArr.length ; i++)\n\t{\n\t\tif (inArr[i].basename.indexOf(\"indel\") >= 0)\n\t\t{\n\t\t\tarr.push(inArr[i]);\n\t\t}\n\t}\n\treturn arr;\n}\n\n/**\n * workflowName - the name of the workflow to filter for.\n * vcfType - the type of VCF (snv, indel, etc...)\n * inArr - an array of files (File[]) to search through.\n */\nfunction filterFor(workflowName, vcfType, inArr)\n{\n\tvar arr = [];\n\tfor (var i = 0; i < inArr.length; i++)\n\t{\n\t\tif (typeof(inArr[i]) == \"string\") //(\"class\" in inArr[i] && inArr[i].class == \"File\")\n\t\t{\n\t\t\tif (inArr[i].indexOf(workflowName) >= 0 && inArr[i].indexOf(vcfType) >= 0)\n\t\t\t{\n\t\t\t\tarr.push(inArr[i])\n\t\t\t}\n\t\t}\n\t\telse\n\t\t{\n\t\t\tif (\"class\" in inArr[i] && inArr[i].class == \"File\")\n\t\t\t{\n\t\t\t\tif (inArr[i].basename.indexOf(workflowName) >= 0 && inArr[i].basename.indexOf(vcfType) >= 0)\n\t\t\t\t{\n\t\t\t\t\tarr.push(inArr[i])\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\t}\n\treturn arr;\n}\n",
                        "\nfunction formatArray(arr)\n{\n\tvar files = \"\";\n\tfor (var i = 0; i < arr.length; i++)\n\t{\n\t\tfiles = files.concat(arr[i].path,\",\");\n\t}\n\treturn files;\n}\n"
                    ]
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/vcfdir",
                    "type": "Directory",
                    "doc": "The directory where the files are"
                },
                {
                    "id": "#main/filesToPreprocess",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "doc": "The files to process"
                },
                {
                    "id": "#main/ref",
                    "type": "File",
                    "doc": "Reference file, used for normalized INDELs"
                },
                {
                    "id": "#main/out_dir",
                    "type": "string",
                    "doc": "The name of the output directory"
                }
            ],
            "outputs": [
                {
                    "type": "#PreprocessedFilesType.yaml/PreprocessedFileset",
                    "outputSource": "#main/populate_output_record/output_record",
                    "id": "#main/preprocessedFiles"
                }
            ],
            "steps": [
                {
                    "doc": "Clean the VCFs.",
                    "run": "#clean_vcf.cwl",
                    "scatter": [
                        "#main/clean/vcf"
                    ],
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/clean/vcf"
                        }
                    ],
                    "out": [
                        "#main/clean/clean_vcf"
                    ],
                    "id": "#main/clean"
                },
                {
                    "doc": "Clean the MUSE VCFs.",
                    "run": "#clean_vcf.cwl",
                    "scatter": [
                        "#main/clean_muse/vcf"
                    ],
                    "in": [
                        {
                            "source": "#main/gather_muse_snvs_for_cleaning/snvs_for_cleaning",
                            "id": "#main/clean_muse/vcf"
                        }
                    ],
                    "out": [
                        "#main/clean_muse/clean_vcf"
                    ],
                    "id": "#main/clean_muse"
                },
                {
                    "doc": "Extract SNVs from normalized INDELs",
                    "run": "#extract_snv.cwl",
                    "scatter": "#main/extract_snv/vcf",
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/extract_snv/vcf"
                        }
                    ],
                    "out": [
                        "#main/extract_snv/extracted_snvs"
                    ],
                    "id": "#main/extract_snv"
                },
                {
                    "doc": "Filters the input list and selects the INDEL VCFs.",
                    "in": [
                        {
                            "source": "#main/clean/clean_vcf",
                            "id": "#main/filter_for_indel/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_for_indel/out_vcf"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/filter_for_indel/aa5d9f22-dd21-4a56-9db1-90e5ae6dfce9/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/filter_for_indel/aa5d9f22-dd21-4a56-9db1-90e5ae6dfce9/out_vcf"
                            }
                        ],
                        "expression": "$({ out_vcf: filterForIndels(inputs.in_vcf) })\n",
                        "id": "#main/filter_for_indel/aa5d9f22-dd21-4a56-9db1-90e5ae6dfce9"
                    },
                    "id": "#main/filter_for_indel"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/gather_broad_indels/normalized_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_broad_indels/indels_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_indels/630b769e-3755-4397-949a-d21478d9b3ea/normalized_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_indels/630b769e-3755-4397-949a-d21478d9b3ea/indels_for_merge"
                            }
                        ],
                        "expression": "$({ indels_for_merge: filterFor(\"broad-snowman\",\"indel\",inputs.normalized_vcfs) })\n",
                        "id": "#main/gather_broad_indels/630b769e-3755-4397-949a-d21478d9b3ea"
                    },
                    "id": "#main/gather_broad_indels"
                },
                {
                    "in": [
                        {
                            "source": "#main/clean/clean_vcf",
                            "id": "#main/gather_broad_snvs/clean_vcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/gather_broad_snvs/extracted_snvs"
                        }
                    ],
                    "out": [
                        "#main/gather_broad_snvs/snvs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_snvs/be877a74-acba-4470-87d7-e6392d87bb0a/clean_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_snvs/be877a74-acba-4470-87d7-e6392d87bb0a/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_snvs/be877a74-acba-4470-87d7-e6392d87bb0a/snvs_for_merge"
                            }
                        ],
                        "expression": "$({\n    snvs_for_merge: ( (filterFor(\"broad-mutect\",\"snv_mnv\",inputs.clean_vcfs)).concat(filterFor(\"broad-mutect\",\"snv_mnv\",inputs.extracted_snvs)) )\n})\n",
                        "id": "#main/gather_broad_snvs/be877a74-acba-4470-87d7-e6392d87bb0a"
                    },
                    "id": "#main/gather_broad_snvs"
                },
                {
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/gather_broad_svs/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/gather_broad_svs/svs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_svs/b727a35e-22ac-45cb-b22f-7d5e410be1f9/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_svs/b727a35e-22ac-45cb-b22f-7d5e410be1f9/svs_for_merge"
                            }
                        ],
                        "expression": "$({ svs_for_merge: filterFor(\"broad-dRanger_snowman\",\".sv.\",inputs.in_vcf) })\n",
                        "id": "#main/gather_broad_svs/b727a35e-22ac-45cb-b22f-7d5e410be1f9"
                    },
                    "id": "#main/gather_broad_svs"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/gather_dkfz_embl_indels/normalized_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_dkfz_embl_indels/indels_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_indels/9d8d2b4b-0385-4cd6-8875-481fde35c8f2/normalized_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_indels/9d8d2b4b-0385-4cd6-8875-481fde35c8f2/indels_for_merge"
                            }
                        ],
                        "expression": "$({ indels_for_merge: filterFor(\"dkfz-indelCalling\",\"indel\",inputs.normalized_vcfs) })\n",
                        "id": "#main/gather_dkfz_embl_indels/9d8d2b4b-0385-4cd6-8875-481fde35c8f2"
                    },
                    "id": "#main/gather_dkfz_embl_indels"
                },
                {
                    "in": [
                        {
                            "source": "#main/clean/clean_vcf",
                            "id": "#main/gather_dkfz_embl_snvs/clean_vcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/gather_dkfz_embl_snvs/extracted_snvs"
                        }
                    ],
                    "out": [
                        "#main/gather_dkfz_embl_snvs/snvs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_snvs/1543797c-dff7-421a-8da9-d666697317bd/clean_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_snvs/1543797c-dff7-421a-8da9-d666697317bd/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_snvs/1543797c-dff7-421a-8da9-d666697317bd/snvs_for_merge"
                            }
                        ],
                        "expression": "$({\n    snvs_for_merge: ( (filterFor(\"dkfz-snvCalling\",\"snv_mnv\",inputs.clean_vcfs)).concat(filterFor(\"dkfz-snvCalling\",\"snv_mnv\",inputs.extracted_snvs)) )\n})\n",
                        "id": "#main/gather_dkfz_embl_snvs/1543797c-dff7-421a-8da9-d666697317bd"
                    },
                    "id": "#main/gather_dkfz_embl_snvs"
                },
                {
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/gather_dkfz_embl_svs/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/gather_dkfz_embl_svs/svs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_svs/b5603983-c811-4954-ba23-a451b95104e0/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_svs/b5603983-c811-4954-ba23-a451b95104e0/svs_for_merge"
                            }
                        ],
                        "expression": "$({ svs_for_merge: filterFor(\"embl-delly\",\".sv.\",inputs.in_vcf) })\n",
                        "id": "#main/gather_dkfz_embl_svs/b5603983-c811-4954-ba23-a451b95104e0"
                    },
                    "id": "#main/gather_dkfz_embl_svs"
                },
                {
                    "in": [
                        {
                            "source": "#main/clean_muse/clean_vcf",
                            "id": "#main/gather_muse_snvs/clean_vcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/gather_muse_snvs/extracted_snvs"
                        }
                    ],
                    "out": [
                        "#main/gather_muse_snvs/snvs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_muse_snvs/8c31fa90-30fb-4b79-a0ea-f36c3165967b/clean_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_muse_snvs/8c31fa90-30fb-4b79-a0ea-f36c3165967b/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_muse_snvs/8c31fa90-30fb-4b79-a0ea-f36c3165967b/snvs_for_merge"
                            }
                        ],
                        "expression": "$({\n    snvs_for_merge: ( filterFor(\"MUSE\",\"snv_mnv\",inputs.clean_vcfs)).concat(filterFor(\"MUSE\",\"snv_mnv\",inputs.extracted_snvs))\n})\n",
                        "id": "#main/gather_muse_snvs/8c31fa90-30fb-4b79-a0ea-f36c3165967b"
                    },
                    "id": "#main/gather_muse_snvs"
                },
                {
                    "in": [
                        {
                            "source": "#main/vcfdir",
                            "id": "#main/gather_muse_snvs_for_cleaning/vcfdir"
                        },
                        {
                            "source": "#main/filesToPreprocess",
                            "id": "#main/gather_muse_snvs_for_cleaning/vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_muse_snvs_for_cleaning/snvs_for_cleaning"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": "Directory",
                                "id": "#main/gather_muse_snvs_for_cleaning/e8af0f16-ca21-42fa-8a86-b9abbfccbf5f/vcfdir"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "string"
                                },
                                "id": "#main/gather_muse_snvs_for_cleaning/e8af0f16-ca21-42fa-8a86-b9abbfccbf5f/vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_muse_snvs_for_cleaning/e8af0f16-ca21-42fa-8a86-b9abbfccbf5f/snvs_for_cleaning"
                            }
                        ],
                        "expression": "$({\n    snvs_for_cleaning: (  filterFor(\"MUSE\",\"snv_mnv\", inputs.vcfs ).map(function(e) {\n        e = { \"class\":\"File\", \"location\":inputs.vcfdir.location+\"/\"+e }\n        return e;\n    } )  )\n})\n",
                        "id": "#main/gather_muse_snvs_for_cleaning/e8af0f16-ca21-42fa-8a86-b9abbfccbf5f"
                    },
                    "id": "#main/gather_muse_snvs_for_cleaning"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/gather_sanger_indels/normalized_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_sanger_indels/indels_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_indels/149f0551-8b5a-448b-8b2c-661f5384d6f5/normalized_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_indels/149f0551-8b5a-448b-8b2c-661f5384d6f5/indels_for_merge"
                            }
                        ],
                        "expression": "$({ indels_for_merge: filterFor(\"svcp\",\"indel\",inputs.normalized_vcfs) })\n",
                        "id": "#main/gather_sanger_indels/149f0551-8b5a-448b-8b2c-661f5384d6f5"
                    },
                    "id": "#main/gather_sanger_indels"
                },
                {
                    "in": [
                        {
                            "source": "#main/clean/clean_vcf",
                            "id": "#main/gather_sanger_snvs/clean_vcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/gather_sanger_snvs/extracted_snvs"
                        }
                    ],
                    "out": [
                        "#main/gather_sanger_snvs/snvs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_snvs/de097087-0626-4ad3-9cd9-e62d8b90b677/clean_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_snvs/de097087-0626-4ad3-9cd9-e62d8b90b677/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_snvs/de097087-0626-4ad3-9cd9-e62d8b90b677/snvs_for_merge"
                            }
                        ],
                        "expression": "$({\n    snvs_for_merge: ( (filterFor(\"svcp\",\"snv_mnv\",inputs.clean_vcfs)).concat(filterFor(\"svcp\",\"snv_mnv\",inputs.extracted_snvs)) )\n})\n",
                        "id": "#main/gather_sanger_snvs/de097087-0626-4ad3-9cd9-e62d8b90b677"
                    },
                    "id": "#main/gather_sanger_snvs"
                },
                {
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/gather_sanger_svs/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/gather_sanger_svs/svs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_svs/0423ba92-09ed-4817-9d2c-219a0cb00f7a/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_svs/0423ba92-09ed-4817-9d2c-219a0cb00f7a/svs_for_merge"
                            }
                        ],
                        "expression": "$({ svs_for_merge: filterFor(\"svfix\",\".sv.\",inputs.in_vcf) })\n",
                        "id": "#main/gather_sanger_svs/0423ba92-09ed-4817-9d2c-219a0cb00f7a"
                    },
                    "id": "#main/gather_sanger_svs"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/gather_smufin_indels/normalized_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_smufin_indels/indels_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_smufin_indels/a914bab2-a27f-4b0d-a4cd-b4aae70c16a5/normalized_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_smufin_indels/a914bab2-a27f-4b0d-a4cd-b4aae70c16a5/indels_for_merge"
                            }
                        ],
                        "expression": "$({ indels_for_merge: filterFor(\"smufin\",\"indel\",inputs.normalized_vcfs) })\n",
                        "id": "#main/gather_smufin_indels/a914bab2-a27f-4b0d-a4cd-b4aae70c16a5"
                    },
                    "id": "#main/gather_smufin_indels"
                },
                {
                    "doc": "Perform VCF merge by type (SNV, SV, INDEL) across workflows.",
                    "run": "#vcf_merge.cwl",
                    "in": [
                        {
                            "source": "#main/gather_broad_indels/indels_for_merge",
                            "id": "#main/merge_vcfs/broad_indel"
                        },
                        {
                            "source": "#main/gather_broad_snvs/snvs_for_merge",
                            "id": "#main/merge_vcfs/broad_snv"
                        },
                        {
                            "source": "#main/gather_broad_svs/svs_for_merge",
                            "id": "#main/merge_vcfs/broad_sv"
                        },
                        {
                            "source": "#main/gather_dkfz_embl_indels/indels_for_merge",
                            "id": "#main/merge_vcfs/de_indel"
                        },
                        {
                            "source": "#main/gather_dkfz_embl_snvs/snvs_for_merge",
                            "id": "#main/merge_vcfs/de_snv"
                        },
                        {
                            "source": "#main/gather_dkfz_embl_svs/svs_for_merge",
                            "id": "#main/merge_vcfs/de_sv"
                        },
                        {
                            "source": "#main/gather_muse_snvs/snvs_for_merge",
                            "id": "#main/merge_vcfs/muse_snv"
                        },
                        {
                            "source": "#main/out_dir",
                            "id": "#main/merge_vcfs/out_dir"
                        },
                        {
                            "source": "#main/gather_sanger_indels/indels_for_merge",
                            "id": "#main/merge_vcfs/sanger_indel"
                        },
                        {
                            "source": "#main/gather_sanger_snvs/snvs_for_merge",
                            "id": "#main/merge_vcfs/sanger_snv"
                        },
                        {
                            "source": "#main/gather_sanger_svs/svs_for_merge",
                            "id": "#main/merge_vcfs/sanger_sv"
                        },
                        {
                            "source": "#main/gather_smufin_indels/indels_for_merge",
                            "id": "#main/merge_vcfs/smufin_indel"
                        }
                    ],
                    "out": [
                        "#main/merge_vcfs/output"
                    ],
                    "id": "#main/merge_vcfs"
                },
                {
                    "doc": "Normalize the INDEL VCFs.",
                    "run": "#normalize.cwl",
                    "scatter": "#main/normalize/vcf",
                    "in": [
                        {
                            "source": "#main/ref",
                            "id": "#main/normalize/ref"
                        },
                        {
                            "source": "#main/filter_for_indel/out_vcf",
                            "id": "#main/normalize/vcf"
                        }
                    ],
                    "out": [
                        "#main/normalize/normalized-vcf"
                    ],
                    "id": "#main/normalize"
                },
                {
                    "in": [
                        {
                            "source": "#main/extract_snv/extracted_snvs",
                            "id": "#main/null_filter_extracted_snvs/extracted_snvs"
                        },
                        {
                            "source": "#main/clean_muse/clean_vcf",
                            "id": "#main/null_filter_extracted_snvs/muse_files"
                        }
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": [
                                        "File",
                                        "null"
                                    ]
                                },
                                "id": "#main/null_filter_extracted_snvs/2da976c8-722d-455e-ac18-67f4dd79cb63/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/null_filter_extracted_snvs/2da976c8-722d-455e-ac18-67f4dd79cb63/cleaned_extracted_snvs"
                            }
                        ],
                        "expression": "$(\n    { cleaned_extracted_snvs: inputs.extracted_snvs.filter(function(n){return n != null}) }\n)\n",
                        "id": "#main/null_filter_extracted_snvs/2da976c8-722d-455e-ac18-67f4dd79cb63"
                    },
                    "out": [
                        "#main/null_filter_extracted_snvs/cleaned_extracted_snvs"
                    ],
                    "id": "#main/null_filter_extracted_snvs"
                },
                {
                    "doc": "Filter out non-PASS lines from the VCFs in filesToProcess.",
                    "in": [
                        {
                            "source": [
                                "#main/filesToPreprocess"
                            ],
                            "valueFrom": "${\n    var VCFs = []\n    for (var i in self)\n    {\n        if (self[i].toLowerCase().indexOf(\"muse\") == -1)\n        {\n            VCFs.push(self[i]);\n        }\n    }\n    return VCFs;\n}\n",
                            "id": "#main/pass_filter/filesToFilter"
                        },
                        {
                            "source": "#main/vcfdir",
                            "id": "#main/pass_filter/vcfdir"
                        }
                    ],
                    "run": "#pass-filter.cwl",
                    "out": [
                        "#main/pass_filter/output"
                    ],
                    "id": "#main/pass_filter"
                },
                {
                    "in": [
                        {
                            "source": "#main/clean/clean_vcf",
                            "id": "#main/populate_output_record/cleanedVcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/populate_output_record/extractedSnvs"
                        },
                        {
                            "source": "#main/merge_vcfs/output",
                            "id": "#main/populate_output_record/mergedVcfs"
                        },
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/populate_output_record/normalizedVcfs"
                        }
                    ],
                    "out": [
                        "#main/populate_output_record/output_record"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/populate_output_record/4318f4be-9211-4cad-8fac-5948a8973194/mergedVcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "#PreprocessedFilesType.yaml/PreprocessedFileset",
                                "id": "#main/populate_output_record/4318f4be-9211-4cad-8fac-5948a8973194/output_record"
                            }
                        ],
                        "expression": "$(\n    {output_record: {\n        \"mergedVcfs\": inputs.mergedVcfs,\n    }}\n)\n",
                        "id": "#main/populate_output_record/4318f4be-9211-4cad-8fac-5948a8973194"
                    },
                    "id": "#main/populate_output_record"
                }
            ],
            "id": "#main",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "CommandLineTool",
            "id": "#vcf_merge.cwl",
            "label": "merge_vcfs",
            "doc": "This tool will merge VCFs by type (SV, SNV, INDEL). This CWL wrapper was written by Solomon Shorser.\nThe Perl script was originaly written by Brian O'Connor and maintained by Solomon Shorser.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "\nfunction formatArray(arr)\n{\n\tvar files = \"\";\n\tfor (var i = 0; i < arr.length; i++)\n\t{\n\t\tfiles = files.concat(arr[i].path,\",\");\n\t}\n\treturn files;\n}\n"
                    ]
                }
            ],
            "inputs": [
                {
                    "id": "#vcf_merge.cwl/broad_snv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/sanger_snv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/de_snv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/muse_snv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/broad_sv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/sanger_sv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/de_sv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/broad_indel",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/sanger_indel",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/de_indel",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/smufin_indel",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/out_dir",
                    "type": "string",
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--outdir"
                    }
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.clean.sorted.vcf.gz"
                    },
                    "id": "#vcf_merge.cwl/merge_vcfs/output"
                }
            ],
            "arguments": [
                {
                    "prefix": "--broad_snv",
                    "valueFrom": "$(formatArray(inputs.broad_snv))"
                },
                {
                    "prefix": "--sanger_snv",
                    "valueFrom": "$(formatArray(inputs.sanger_snv))"
                },
                {
                    "prefix": "--dkfz_embl_snv",
                    "valueFrom": "$(formatArray(inputs.de_snv))"
                },
                {
                    "prefix": "--muse_snv",
                    "valueFrom": "$(formatArray(inputs.muse_snv))"
                },
                {
                    "prefix": "--broad_sv",
                    "valueFrom": "$(formatArray(inputs.broad_sv))"
                },
                {
                    "prefix": "--sanger_sv",
                    "valueFrom": "$(formatArray(inputs.sanger_sv))"
                },
                {
                    "prefix": "--dkfz_embl_sv",
                    "valueFrom": "$(formatArray(inputs.de_sv))"
                },
                {
                    "prefix": "--broad_indel",
                    "valueFrom": "$(formatArray(inputs.broad_indel))"
                },
                {
                    "prefix": "--sanger_indel",
                    "valueFrom": "$(formatArray(inputs.sanger_indel))"
                },
                {
                    "prefix": "--dkfz_embl_indel",
                    "valueFrom": "$(formatArray(inputs.de_indel))"
                },
                {
                    "prefix": "--smufin_indel",
                    "valueFrom": "$(formatArray(inputs.smufin_indel))"
                }
            ],
            "baseCommand": "/opt/oxog_scripts/vcf_merge_by_type.pl",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        }
    ],
    "cwlVersion": "v1.0"
}
